]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Fix compiler warnings/errors due to -Wall.
[pulseview.git] / main.cpp
index a7ab89fbf7422ada41d7050ac57715ce33f7f05d..ba8e787069be74066f510c3e1ab28a3459a8401a 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -34,6 +34,9 @@ extern "C" {
 
 #include "config.h"
 
+// Global pointer to our QApplication
+QApplication *g_app = NULL;
+
 void usage()
 {
        fprintf(stderr,
@@ -47,15 +50,16 @@ void usage()
 }
 
 /*
* SIGINT handler (likely recieved Ctrl-C from terminal)
  */
-void sigint(int param)
+void sigint_handler(int param)
 {
-       (void) param;
-       
-       qDebug("pv: Recieved SIGINT");
-       
-       /* TODO: Handle SIGINT */
+       (void)param;
+
+       qDebug("Received SIGINT.");
+
+       if (g_app)
+               g_app->quit();
 }
 
 int main(int argc, char *argv[])
@@ -64,9 +68,11 @@ int main(int argc, char *argv[])
        struct sr_context *sr_ctx = NULL;
 
        // Register a SIGINT handler
-       signal (SIGINT, sigint);
+       signal(SIGINT, sigint_handler);
 
        QApplication a(argc, argv);
+       // Now we have an application to populate our global pointer
+       g_app = &a;
 
        // Set some application metadata
        QApplication::setApplicationVersion(PV_VERSION_STRING);
@@ -47,15 +50,16 @@ void usage()
 
 /*
- * SIGINT handler (likely recieved Ctrl-C from terminal)
+ * SIGINT handler (likely received Ctrl-C from terminal)
  */